
# Kube app library process flow documentation

## Pre-requisites
Python installation documentation

Python installation for windows 8 and above.
[Documentation](https://linktodocumentation)

pip installation for windows 8 and above.
[Documentation](https://linktodocumentation)

## Installation



### Supported for all macOS/linux/windows.
There are some prerequisite which need to be considered before using this sdk and they have been covered in previous section.

Install kube-app sdk with pip.


## Method:

### pushData(source_data,table,overwrite)

Using pushData method data can be inserted into table schema already defined in kube database.

```bash
  import kube_app as k
  client = k.Client('API_KEY','SECRET_KEY','Entity_Name')
  client.pushData(source_data,table,overwrite)
```

### Request Parameters

Here is the list of parameters for pushing data into kube database:

| Parameter | Type     | Description                |
| :-------- | :------- | :------------------------- |
| `source_data` | `pandas dataframe` | source_data is pandas dataframe which is generated by the user. |
| `table` | `string` | table is string value which can be: sales,sales_order,calendar,ar,logs,target. |
| `overwrite` | `boolean` | overwrite can be True or False. overwrite is True by default and when it is False then data is appended in current table. |

